==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24ToolBarFocusListener.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$ToolBarFocusListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f661b4990a12b1b9 javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener_H_

// Forward structure declarations
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_java_awt_event_FocusEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_java_awt_event_FocusEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_java_awt_event_FocusEvent$object *);
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_java_awt_event_FocusEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24ToolBarFocusListener.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$ToolBarFocusListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b687000f59944dde javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener_H_

// Forward structure declarations
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarFocusListener_H_ */
